@@ -1,9 +1,9 @@
 ## File Name: tam_jml_version2_calc_xsi.R
-## File Version: 9.576
+## File Version: 9.618
 
 tam_jml_version2_calc_xsi <- function ( resp, resp.ind, A, A.0, B, nstud, nitems,
             maxK, convM, ItemScore, theta, xsi, Msteps, pweightsM,
-            est.xsi.index, rp3, rp3.sel, rp3.pweightsM, damp=0 )
+            est.xsi.index, rp3, rp3.sel, rp3.pweightsM, damp=0, version=2 )
 {
 
     #Update item parameters
@@ -32,26 +32,55 @@ tam_jml_version2_calc_xsi <- function ( resp, resp.ind, A, A.0, B, nstud, nitems
     nonest.xsi.index <- setdiff( seq(1,PP1), est.xsi.index )
     convergeP[ nonest.xsi.index ] <- TRUE
 
+    nstud3 <- nrow(rp3.sel)
+
+
     # begin loop
     iterP <- 1
     old_increment <- rep(5,PP1)
     cat(" Item parameter estimation |")
-    while (!convergeAllP & ( iterP <=Msteps ) & est_xsi ) {
-        res.p <- tam_mml_calc_prob( iIndex=1:nitems, A=A, AXsi=AXsi,
-                                B=B, xsi=xsi, theta=theta[ rp3.sel$caseid,,drop=FALSE ],
-                                nnodes=nrow(rp3.sel), maxK=maxK, recalc=TRUE )
-        rprobs <- res.p$rprobs
-        M1 <- resp.ind[ rp3.sel$caseid, ] * rp3.pweightsM
-        t_rprobs <- aperm( rprobs, dim=c(3,2,1) )
-        for (k1 in 1:maxK) {
-            M1_k1 <- t_rprobs[,k1,] * M1
-            r[,k1] <- colSums( M1_k1, na.rm=TRUE)
-            for (k2 in 1:maxK) {
-                rr[,k1,k2] <- colSums( M1_k1 * t_rprobs[,k2,], na.rm=TRUE)
-            }
+
+a0 <- Sys.time()
+
+    #--- iterations
+    while (!convergeAllP & ( iterP <=Msteps ) & est_xsi ){
+        theta_sel <- theta[ rp3.sel$caseid,,drop=FALSE ]
+
+        if (version==2){
+            res.p <- tam_mml_calc_prob( iIndex=1:nitems, A=A, AXsi=AXsi,
+                                    B=B, xsi=xsi, theta=theta_sel,
+                                    nnodes=nstud3, maxK=maxK, recalc=TRUE )
+            rprobs <- res.p$rprobs
         }
 
-        A_Sq <- AA_bari <- A_bari <- matrix( 0, PP1, nitems )
+        if (version==3){
+            AXsi <- tam_jml_calc_xsi_compute_AXsi(A=A, xsi=xsi)
+            res <- tam_rcpp_tam_jml_calc_probs(theta=as.vector(theta_sel), AXsi=AXsi,
+                        B=B[,,1], maxK=maxK, resp_ind=resp.ind[rp3.sel$caseid,]  )
+            rprobs <- array(res$probs, dim=c(nitems,maxK,nstud3))
+        }
+# cat("\n probs ") ; a1 <- Sys.time(); print(a1-a0) ; a0 <- a1
+        resp_ind_sel <- resp.ind[ rp3.sel$caseid, ]
+
+        if (version==2){
+            M1 <- resp_ind_sel*rp3.pweightsM
+            t_rprobs <- aperm( rprobs, dim=c(3,2,1) )
+            for (k1 in 1:maxK) {
+                M1_k1 <- t_rprobs[,k1,] * M1
+                r[,k1] <- colSums( M1_k1, na.rm=TRUE)
+                for (k2 in 1:maxK) {
+                    rr[,k1,k2] <- colSums( M1_k1 * t_rprobs[,k2,], na.rm=TRUE)
+                }
+            }
+        }
+        if (version==3){
+            res <- tam_rcpp_tam_jml_calc_xsi_rr(resp_ind=resp_ind_sel,
+                            rprobs=rprobs, maxK=maxK, pweightsM=rp3.pweightsM)
+            rr <- array( res$rr, dim=c(nitems,maxK,maxK) )
+            r <- res$r
+        }
+
+        A_Sq <- AA_bari <- A_bari <- matrix( 0, nrow=PP1, ncol=nitems)
         t_r <- t(r)
         t_rr <- aperm( rr, dim=c(3,2,1) )
         t_A.0 <- aperm( A.0, dim=c(3,2,1) )
@@ -88,6 +117,7 @@ tam_jml_version2_calc_xsi <- function ( resp, resp.ind, A, A.0, B, nstud, nitems
         p_loop <- est.xsi.index[convergeP[est.xsi.index]==FALSE]
         convergeAllP <- (sum(convergeP[est.xsi.index])==length(est.xsi.index))
         cat("-")
+
     } # end of all parameters convergence
 
     # dampening increments
